@@ -16,6 +16,12 @@ def main(render_only=False):
             '-p',
             help='Build a pipeline partially until certain task',
             default=None)
+        parser.add_argument(
+            '--debug',
+            '-d',
+            help='Drop a debugger session if an exception happens',
+            action='store_true',
+            default=False)
 
     dag, args = _custom_command(parser)
 
@@ -23,10 +29,13 @@ def main(render_only=False):
         dag.render()
     else:
         if args.partially:
-            report = dag.build_partially(args.partially, force=args.force)
+            report = dag.build_partially(args.partially,
+                                         force=args.force,
+                                         debug=args.debug)
         else:
-            report = dag.build(force=args.force)
+            report = dag.build(force=args.force, debug=args.debug)
 
-        print(report)
+        if report:
+            print(report)
 
     return dag
