@@ -121,7 +121,10 @@ class NotebookSource(Source):
             self._ext_in = ext_in
 
         # try to determine language based on extension, though this test
-        # mught be inconclusive if dealing with a ipynb file
+        # might be inconclusive if dealing with a ipynb file, though we only
+        # use this to determine the appropriate jupyter kernel when
+        # initializing from a string, when initializing from files, the
+        # extension is used to determine the kernel
         self._language = determine_language(self._ext_in)
 
         self._loc = None
@@ -170,7 +173,7 @@ class NotebookSource(Source):
         Path(tmp_in).unlink()
         tmp_out.unlink()
 
-        self._post_render_validation(self._params)
+        self._post_render_validation(self._params, self._nb_str_rendered)
 
     def _read_nb_str_unrendered(self):
         """
@@ -220,17 +223,14 @@ class NotebookSource(Source):
                 'Notebook{} does not have a cell tagged '
                 '"parameters"'.format(loc))
 
-    def _post_render_validation(self, params):
+    def _post_render_validation(self, params, nb_str):
         """
         Validate params passed against parameters in the notebook
         """
         if self.static_analysis:
             if self.language == 'python':
-                # read the notebook with the injected parameters from the tmp
-                # location
-                check_notebook(self.nb_obj_rendered,
-                               params,
-                               filename=self._path or 'notebook')
+                nb = self._nb_str_to_obj(nb_str)
+                check_notebook(nb, params, filename=self._path or 'notebook')
             else:
                 raise NotImplementedError(
                     'static_analysis is only implemented for Python notebooks'
@@ -254,6 +254,10 @@ class NotebookSource(Source):
 
     @property
     def nb_str_rendered(self):
+        """
+        Returns the notebook (as a string) with parameters injected, hot
+        reloadig if necessary
+        """
         if self._nb_str_rendered is None:
             raise RuntimeError('Attempted to get location for an unrendered '
                                'notebook, render it first')
@@ -265,9 +269,13 @@ class NotebookSource(Source):
 
     @property
     def nb_obj_rendered(self):
+        """
+        Returns the notebook (as an objet) with parameters injected, hot
+        reloadig if necessary
+        """
         if self._nb_obj_rendered is None:
-            self._nb_obj_rendered = (nbformat.reads(
-                self.nb_str_rendered, as_version=nbformat.NO_CONVERT))
+            # using self.nb_str_rendered triggers hot reload if needed
+            self._nb_obj_rendered = self._nb_str_to_obj(self.nb_str_rendered)
 
         return self._nb_obj_rendered
 
@@ -312,6 +320,9 @@ class NotebookSource(Source):
         else:
             return self._language
 
+    def _nb_str_to_obj(self, nb_str):
+        return nbformat.reads(nb_str, as_version=nbformat.NO_CONVERT)
+
     def _get_parameters_cell(self):
         self._read_nb_str_unrendered()
         cell, _ = find_cell_with_tag(self._nb_obj_unrendered, tag='parameters')
@@ -488,12 +499,21 @@ def _to_nb_obj(source, language, ext=None, kernelspec_name=None):
         have this.
     """
     import jupytext
-    import jupyter_client
 
     # let jupytext figure out the format
     nb = jupytext.reads(source, fmt=ext)
 
-    kernel_name = determine_kernel_name(nb, language, kernelspec_name)
+    ensure_kernelspec(nb, kernelspec_name, ext, language)
+
+    return nb
+
+
+def ensure_kernelspec(nb, kernelspec_name, ext, language):
+    """Make sure the passed notebook has kernel info
+    """
+    import jupyter_client
+
+    kernel_name = determine_kernel_name(nb, kernelspec_name, ext, language)
 
     # cannot keep going if we don't have the kernel name
     if kernel_name is None:
@@ -514,30 +534,33 @@ def _to_nb_obj(source, language, ext=None, kernelspec_name=None):
         "name": kernel_name
     }
 
-    return nb
 
+def determine_kernel_name(nb, kernelspec_name, ext, language):
+    """
+    Determines the kernel name by using the following data (returns whatever
+    gives kernel info first): 1) explicit kernel from the user 2) notebook's
+    metadata 3) file extension 4) language 5) best guess
+    """
+    # explicit kernelspec name
+    if kernelspec_name is not None:
+        return kernelspec_name
 
-def determine_kernel_name(nb, language, kernelspec_name):
-    """
-    Try to determine kernel name, first check notebook metadata, then
-    check if the user explicitly provided a kernelspec_name. If None of this
-    works use the language info, which should not be empty by the time this
-    is executed
-    """
+    # use metadata info
     try:
         return nb.metadata.kernelspec.name
     except AttributeError:
         pass
 
-    if kernelspec_name is not None:
-        return kernelspec_name
+    # use language from extension if passed, otherwise use language variable
+    if ext:
+        language = determine_language(ext)
 
-    # two most common cases
     lang2kernel = {'python': 'python3', 'r': 'ir'}
 
     if language in lang2kernel:
         return lang2kernel[language]
 
+    # nothing worked, try to guess if it's python...
     is_python_ = is_python(nb)
 
     if is_python_:
@@ -556,6 +579,11 @@ def inject_cell(model, params):
     """
     nb = nbformat.from_dict(model['content'])
 
+    # we must ensure nb has kernelspec info, otherwise papermill willf fail to
+    # parametrize
+    ext = model['name'].split('.')[-1]
+    ensure_kernelspec(nb, kernelspec_name=None, ext=ext, language=None)
+
     # papermill adds a bunch of things before calling parameterize_notebook
     # if we don't add those things, parameterize_notebook breaks
     # https://github.com/nteract/papermill/blob/0532d499e13e93d8990211be33e9593f1bffbe6c/papermill/iorw.py#L400
@@ -642,7 +670,8 @@ def is_python(nb):
         except SyntaxError:
             is_python_ = False
         else:
-            # there is a lot of R code which is also valid Python code! So let's
+            # there is a lot of R code which is also valid Python code! So
+            # let's
             # run a quick test. It is very unlikely to have "<-" in Python (
             # {less than} {negative} but extremely common {assignment}
             if '<-' not in code_str:
