@@ -1,12 +1,14 @@
 """
 Create Tasks from dictionaries
 """
+from functools import partial
 from copy import copy
 from pathlib import Path
 from collections.abc import MutableMapping, Mapping
 
 from ploomber import tasks, products
-from ploomber.util.util import load_dotted_path, _make_iterable
+from ploomber.util.util import (load_dotted_path, _make_iterable,
+                                locate_dotted_path)
 from ploomber.util import validate
 
 suffix2taskclass = {
@@ -20,7 +22,7 @@ suffix2taskclass = {
 }
 
 
-def task_class_from_source_str(source_str):
+def task_class_from_source_str(source_str, lazy_import):
     """
     The source field in a DAG spec is a string. The actual value needed to
     instantiate the task depends on the task class, but to make task class
@@ -30,11 +32,15 @@ def task_class_from_source_str(source_str):
     """
     extension = Path(source_str).suffix
 
+    # if lazy load, just locate the module without importing it
+    fn_checker = locate_dotted_path if lazy_import else partial(
+        load_dotted_path, raise_=True)
+
     if extension and extension in suffix2taskclass:
         return suffix2taskclass[extension]
     else:
         try:
-            imported = load_dotted_path(source_str, raise_=True)
+            imported = fn_checker(source_str)
             error = None
         except Exception as e:
             imported = None
@@ -52,7 +58,7 @@ def task_class_from_source_str(source_str):
             return tasks.PythonCallable
 
 
-def task_class_from_spec(task_spec):
+def task_class_from_spec(task_spec, lazy_import):
     """
     Returns the class for the TaskSpec, if the spec already has the class
     name (str), it just returns the actual class object with such name,
@@ -63,32 +69,56 @@ def task_class_from_spec(task_spec):
     if class_name:
         class_ = getattr(tasks, class_name)
     else:
-        class_ = task_class_from_source_str(task_spec['source'])
+        class_ = task_class_from_source_str(task_spec['source'], lazy_import)
 
     return class_
 
 
-def source_for_task_class(source_str, task_class):
+def source_for_task_class(source_str, task_class, project_root, lazy_import):
     if task_class is tasks.PythonCallable:
-        return load_dotted_path(source_str)
+        if lazy_import:
+            return source_str
+        else:
+            return load_dotted_path(source_str)
     else:
-        return Path(source_str)
+        path = Path(source_str)
+
+        if project_root and not path.is_absolute():
+            return Path(project_root, source_str)
+        else:
+            return path
 
 
 class TaskSpec(MutableMapping):
-    def __init__(self, data, meta):
+    """
+    A TaskSpec converts dictionaries to Task objects. This class is not
+    intended to be used directly, but through DAGSpec
+
+    Parameters
+    ----------
+    data : dict
+        The data that holds the spec information
+    meta : dict
+        The "meta" section information from the calling DAGSpec
+    project_root : str or pathlib.Path
+        The project root folder (pipeline.yaml parent)
+    """
+    def __init__(self, data, meta, project_root, lazy_import=False):
         # FIXME: make sure data and meta are immutable structures
         self.data = data
         self.meta = meta
+        self.project_root = project_root
+
         self.validate()
 
         # initialize required elements
-        self.data['class'] = task_class_from_spec(self.data)
-        # preprocess source obj, at this point it will either be a Path
-        # if the task requires a file or a callable if it's a PythonCallable
-        # task
+        self.data['class'] = task_class_from_spec(self.data, lazy_import)
+        # preprocess source obj, at this point it will either be a Path if the
+        # task requires a file or a callable if it's a PythonCallable task
         self.data['source'] = source_for_task_class(self.data['source'],
-                                                    self.data['class'])
+                                                    self.data['class'],
+                                                    self.project_root,
+                                                    lazy_import)
 
         source_loader = meta['source_loader']
 
@@ -99,6 +129,9 @@ class TaskSpec(MutableMapping):
             self.data['source'] = source_loader[self.data['source']]
 
     def validate(self):
+        """
+        Validates the data schema
+        """
         if 'upstream' not in self.data:
             self.data['upstream'] = None
 
@@ -124,18 +157,19 @@ class TaskSpec(MutableMapping):
                              'should not have a "product" key'.format(
                                  self.data))
 
-    def to_task(self, dag, root_path):
-        """Returns a Task instance
+    def to_task(self, dag):
+        """Converts the spec to a Task instance and adds it to the dag
         """
         task_dict = copy(self.data)
         upstream = _make_iterable(task_dict.pop('upstream'))
         class_ = task_dict.pop('class')
 
-        product = init_product(task_dict, self.meta, class_, root_path)
+        product = init_product(task_dict, self.meta, class_, self.project_root)
 
         _init_client(task_dict)
 
         source = task_dict.pop('source')
+
         name = task_dict.pop('name', None)
 
         on_finish = task_dict.pop('on_finish', None)
@@ -231,20 +265,16 @@ def init_product(task_dict, meta, task_class, root_path):
 def resolve_product(product_raw, relative_to, class_):
     if class_ != products.File:
         return product_raw
-    else:
+    elif relative_to:
         # When a DAG is initialized, paths are usually relative to the folder
         # that has the pipeline.yaml, the only case when this isn't true is
         # when using DAGSpec.auto_load(), in such case, relative paths won't
         # work if the current working directory is different  to the
         # pipeline.yaml folder (this happens sometimes in the Jupyter UI).
         # We resolve paths to avoid ambiguity on this
-
-        # we call resolve in relative_to and then append the rest because
-        # Python 3.5 raises a FileNotFoundError is calling resolve in a path
-        # that does not exist
-
-        resolved = Path(relative_to).resolve()
-        return str(Path(resolved, product_raw))
+        return str(Path(relative_to, product_raw).resolve())
+    else:
+        return Path(product_raw).resolve()
 
 
 def _init_client(task_dict):
