@@ -1,7 +1,5 @@
-from jinja2 import Template
-
 from ploomber.static_analysis.abstract import Extractor
-from ploomber.static_analysis.jinja import JinjaUpstreamIntrospector
+from ploomber.static_analysis.jinja import JinjaExtractor
 
 
 class StringExtractor(Extractor):
@@ -11,10 +9,8 @@ class StringExtractor(Extractor):
     def extract_upstream(self):
         """Extract upstream keys used in a templated SQL script
         """
-        upstream = JinjaUpstreamIntrospector()
-        params = {'upstream': upstream}
-        Template(self.code).render(params)
-        return set(upstream.keys) if len(upstream.keys) else None
+        extractor = JinjaExtractor(self.code)
+        return extractor.find_variable_access(variable='upstream')
 
     def extract_product(self):
         raise NotImplementedError('extract_product is not implemented in '
