@@ -1,3 +1,4 @@
+import os
 import shlex
 import pdb
 import tempfile
@@ -30,7 +31,7 @@ from ploomber.sources import NotebookSource
 from ploomber.sources.NotebookSource import _cleanup_rendered_nb
 from ploomber.products import File, MetaProduct
 from ploomber.tasks.Task import Task
-from ploomber.util import requires
+from ploomber.util import requires, chdir_code
 
 
 class NotebookConverter:
@@ -38,6 +39,11 @@ class NotebookConverter:
     Thin wrapper around nbconvert to provide a simple API to convert .ipynb
     files to different formats.
 
+    Parameters
+    ----------
+    nbconvert_export_kwargs : dict, default=None
+        Keyword arguments passed to ``nbconvert.export``
+
     Notes
     -----
     The exporter is searched at initialization time to raise an appropriate
@@ -190,14 +196,41 @@ class NotebookRunner(Task):
         upstream dependencies an upstream parameter should also be declared
         "upstream = None"
     nbconvert_export_kwargs : dict
-        Keyword arguments to pass to the nbconvert.export function (this is
+        Keyword arguments to pass to the ``nbconvert.export`` function (this is
         only used if exporting the output ipynb notebook to another format).
         You can use this, for example, to hide code cells using the
-        exclude_input parameter
+        exclude_input parameter. See ``nbconvert`` documentation for details.
     local_execution : bool, optional
         Change working directory to be the parent of the notebook's source.
         Defaults to False. This resembles the default behavior when
         running notebooks interactively via `jupyter notebook`
+
+
+    Examples
+    --------
+    >>> from pathlib import Path
+    >>> from ploomber import DAG
+    >>> from ploomber.tasks import NotebookRunner
+    >>> from ploomber.products import File
+    >>> dag = DAG()
+    >>> # do not include input code (only cell's output)
+    >>> NotebookRunner(Path('nb.ipynb'), File('out-1.html'), dag=dag,
+    ...                nbconvert_export_kwargs={'exclude_input': True},
+    ...                name=1)
+    >>> # Selectively remove cells with the tag "remove"
+    >>> config = {'TagRemovePreprocessor': {'remove_cell_tags': ('remove',)},
+    ...           'HTMLExporter':
+    ...             {'preprocessors':
+    ...             ['nbconvert.preprocessors.TagRemovePreprocessor']}}
+    >>> NotebookRunner(Path('nb.ipynb'), File('out-2.html'), dag=dag,
+    ...                nbconvert_export_kwargs={'config': config},
+    ...                name=2)
+    >>> dag.build()
+
+    Notes
+    -----
+    nbconvert's documentation:
+    https://nbconvert.readthedocs.io/en/latest/config_options.html#preprocessor-options
     """
     PRODUCT_CLASSES_ALLOWED = (File, )
 
@@ -288,8 +321,13 @@ class NotebookRunner(Task):
 
         Notes
         -----
+        Be careful when developing tasks interacively. If the task has run
+        successfully, you overwrite products but don't save the
+        updated source code, your DAG will enter an inconsistent state where
+        the metadata won't match the overwritten product.
+
         If you modify the source code and call develop again, the source
-        code will be updated only if the `hot_reload option` is turned on.
+        code will be updated only if the ``hot_reload option`` is turned on.
         See :class:`ploomber.DAGConfigurator` for details.
         """
         # TODO: this code needs refactoring, should be a context manager
@@ -359,6 +397,20 @@ class NotebookRunner(Task):
         """
         Opens the notebook (with injected parameters) in debug mode in a
         temporary location
+
+        Parameters
+        ----------
+        kind : str, default='ipdb'
+            Debugger to use, 'ipdb' to use line-by-line IPython debugger,
+            'pdb' to use line-by-line Python debugger or 'pm' to to
+            post-portem debugging using IPython
+
+        Notes
+        -----
+        Be careful when debugging tasks. If the task has run
+        successfully, you overwrite products but don't save the
+        updated source code, your DAG will enter an inconsistent state where
+        the metadata won't match the overwritten product.
         """
         if self.source.language != 'python':
             raise NotImplementedError(
@@ -372,7 +424,8 @@ class NotebookRunner(Task):
             raise ValueError('kind must be one of {}'.format(opts))
 
         nb = _read_rendered_notebook(self.source.nb_str_rendered)
-        _, tmp_path = tempfile.mkstemp(suffix='.py')
+        fd, tmp_path = tempfile.mkstemp(suffix='.py')
+        os.close(fd)
         code = jupytext.writes(nb, version=nbformat.NO_CONVERT, fmt='py')
         Path(tmp_path).write_text(code)
 
@@ -413,7 +466,9 @@ class NotebookRunner(Task):
         # we will change the extension after the notebook runs successfully
         path_to_out_ipynb = path_to_out.with_suffix('.ipynb')
 
-        _, tmp = tempfile.mkstemp('.ipynb')
+        fd, tmp = tempfile.mkstemp('.ipynb')
+        os.close(fd)
+
         tmp = Path(tmp)
         tmp.write_text(self.source.nb_str_rendered)
 
@@ -452,9 +507,9 @@ def _read_rendered_notebook(nb_str):
 # Debugging settings (this cell will be removed before saving)
 # change the current working directory to directory of the session that
 # invoked the jupyter app to make relative paths work
-from os import chdir
-chdir("{}")
-""".format(Path('.').resolve())
+import os
+{}
+""".format(chdir_code(Path('.').resolve()))
 
     cell = nbformat_v.new_code_cell(source,
                                     metadata={'tags': ['debugging-settings']})
